/**
 * 
 */
package de.ixxat.vci3;

/**
 * The VCI device manager gives access to the list of installed VCI devices or
 * opens a VCI device. Use the {@link VciServer} class to get a VCI device
 * manager object. When no longer needed the VCI device manager object has to be
 * disposed using the {@link IDisposable} interface.
 * 
 * @author Michael Ummenhofer
 * 
 */
public interface IVciDeviceManager extends IDisposable
{
  /**
   * Opens a Windows GUI Dialog to select the VCI Device. It returns the Unique
   * VCI Device ID necessary to open the device via the function
   * {@link #OpenDevice(long)}.
   * 
   * @deprecated Based on VCI NPL API functions which are optional and 
   * therefore not always present, please use {@link #EnumDevices()} and 
   * {@link #OpenDevice(long)} instead. If the VciNpl.dll fails to load, this 
   * function throws a java.lang.UnsatisfiedLinkError exception.
   * 
   * @return lVciId - Unique VCI Device ID
   * @throws Throwable
   * 
   */
  public long SelectDeviceDialog() throws Throwable;

  /**
   * Returns the VCI device enumerator which manages the list of installed VCI device objects.
   * @return {@link IVciEnumDevice} - The VCI device enumerator interface 
   * @throws Throwable
   */
  public IVciEnumDevice EnumDevices() throws Throwable;

  /**
   * Opens the given VCI device and returns a reference to the
   * {@link IVciDevice} Object.
   * 
   * @param lVciId
   *          Unique VCI Device ID.
   * @return {@link IVciDevice} - The VCI device object interface.
   * @throws Throwable
   */
  public IVciDevice OpenDevice(long lVciId) throws Throwable;

}
