/**
 * 
 */
package de.ixxat.vci3.bal;

import de.ixxat.jni.CPointer;
import de.ixxat.vci3.VciDeviceCapabilities;

/**
 * This value Class represents the BAL Features. The BAL Features
 * can be retrieved by calling {@link IBalObject#GetFeatures()}.
 * 
 * @author Michael Ummenhofer
 *
 */
public class BalFeatures
{
  /** maximum possible bus sockets */
  public static final short BAL_MAX_SOCKETS = VciDeviceCapabilities.VCI_MAX_BUSCTRL;
  
  /** major firmware version number */
  public short m_wFwMajorVersion        = 0;
  /** minor firmware version number */
  public short m_wFwMinorVersion        = 0;
  /** number of supported bus sockets */
  public short m_wBusSocketCount        = 0;
  /** array of supported bus sockets */
  private short m_awBusSocketType[]     = new short[BAL_MAX_SOCKETS];

  /** VCI BUS Type */
  public short    m_awBusType[]         = new short[BAL_MAX_SOCKETS];
  /** VCI Controller Type*/
  public short    m_awSocketType[]      = new short[BAL_MAX_SOCKETS];

  /**
   * Creates a new BAL Features object.
   * @throws Throwable
   */
  protected BalFeatures()
  {
  }

  /**
   * Creates a new BAL Features object.
   * 
   * @param pBalFeatures
   *          CPointer to native memory which contains the BALFEATURES
   *          structure.
   * @throws Throwable
   */
  protected BalFeatures(CPointer pBalFeatures) throws Throwable
  {
    fromCPointer(pBalFeatures);
  }

  /**
   * Updates a existing BAL Features object.
   * 
   * @param pBalFeatures
   *          CPointer to native memory which contains the BALFEATURES
   *          structure.
   * @throws Throwable
   */
  protected void fromCPointer(CPointer pBalFeatures) throws Throwable
  {
    // Update BAL Features
    m_wFwMajorVersion   = pBalFeatures.getShort(0);
    m_wFwMinorVersion   = pBalFeatures.getShort(2);
    m_wBusSocketCount   = pBalFeatures.getShort(4);
    
    // Iterate trough all possible Sockets
    for(short wIndex =0; wIndex < BAL_MAX_SOCKETS; wIndex++)
    {
      if(wIndex < m_wBusSocketCount)
        m_awBusSocketType[wIndex] = pBalFeatures.getShort(6+(wIndex*2));
      else
        m_awBusSocketType[wIndex] = VciDeviceCapabilities.VCI_BUS_RES;

      m_awBusType[wIndex]         = (short)((m_awBusSocketType[wIndex] >> 8) & 0x00FF);
      m_awSocketType[wIndex]      = (short)((m_awBusSocketType[wIndex] >> 0) & 0x00FF);
    }
  }

  /**
   * Returns the BAL Features as string.
   * @return The BAL Features as string.
   */
  public String toString()
  {
    String strBalFeatures = "";
    strBalFeatures += "FW Version: " + m_wFwMajorVersion + "." + m_wFwMinorVersion + ", ";
    strBalFeatures += "Socket count: " + m_wBusSocketCount + " (Bus, Socket) -> {";
    
    // Iterate trough all available Sockets
    for(short wIndex =0; wIndex < m_wBusSocketCount; wIndex++)
    {
      strBalFeatures += "(" + m_awBusType[wIndex] + ", ";
      strBalFeatures += m_awSocketType[wIndex]+ ")";
      if((wIndex+1) < m_wBusSocketCount)
        strBalFeatures += ", ";
      else
        strBalFeatures += "}";
    }

    return strBalFeatures;
  }

}
