/**
 * 
 */
package de.ixxat.vci3.bal.can;

import de.ixxat.jni.*;
import de.ixxat.vci3.bal.FifoReader;

/**
 * This class implements the interface {@link ICanMessageReader} which
 * represents a CAN message reader.
 * 
 * @see ICanMessageReader
 * @author Michael Ummenhofer
 * 
 */
public class CanMessageReader extends FifoReader implements ICanMessageReader
{

  /**
   * constructor
   * @param pIFifoReader
   * @throws Throwable
   */
  protected CanMessageReader(CMalloc pIFifoReader) throws Throwable
  {
    super(pIFifoReader);
    //System.out.println("CanMessageReader::CanMessageReader");
    
  }

  /**
   * Clean up Object
   * @throws Throwable
   */
  protected void finalize() throws Throwable
  {
    try
    {
      Dispose();
    }
    finally
    {
      // Call finalize of base class
      super.finalize();
    }
  }
  
  /**
   * @see de.ixxat.jni.CInterface#Dispose()
   * @throws Throwable
   */
  public void Dispose() throws Throwable
  {
    try
    {
    }
    finally
    {
      // Call Base Class
      super.Dispose();
    }
  }
 
  /**
   * @see ICanMessageReader#ReadMessage()
   * @return {@link CanMessage}
   * @throws Throwable
   */
  public CanMessage ReadMessage() throws Throwable
  {
    return ReadMessage(null);
  }
  
  /**
   * @see ICanMessageReader#ReadMessage(CanMessage)
   * @return {@link CanMessage}
   * @throws Throwable
   */
  public CanMessage ReadMessage(CanMessage oCanMsg) throws Throwable
  {
    CanMessage  oCanMsgLocal  = null;
    CPointer    pData         = null;
    
    synchronized (this)
    {
      try
      {
        // Lock access to FiFo
        super.Lock();

        // Try to get a CAN Message
        pData = super.AcquireRead();
        
        // Copy Message and Release FiFo Entry
        if(pData != null)
        {
          // Try to convert message
          try
          {
            // Create new CAN Message or update existing message
            if(oCanMsg == null)
            {
              oCanMsgLocal = new CanMessage(pData);
            }
            else
            {
              oCanMsg.fromCPointer(pData);
              oCanMsgLocal = oCanMsg;
            }
          }
          finally
          {
            // Release one message form queue
            // any failed to convert messages, too
            super.ReleaseRead();
          }
        }
      }
      finally
      {
        // Unlock access to FiFo
        super.Unlock();
      }
    }
    
    return oCanMsgLocal;
  }

}
